@@ -1,6 +1,6 @@
 from conans.client.graph.graph import CONTEXT_BUILD
 from conan.errors import ConanException
-from conans.model.recipe_ref import ref_matches
+from conan.internal.model.recipe_ref import ref_matches
 
 
 def initialize_conanfile_profile(conanfile, profile_build, profile_host, base_context,
